@@ -13,7 +13,7 @@ func createEvaluateSequenceCommand() *cobra.Command {
 	var cmdEvalSequence = &cobra.Command{
 		Use:     "eval [expression] [yaml_file1]...",
 		Aliases: []string{"e"},
-		Short:   "Apply the expression to each document in each yaml file in sequence",
+		Short:   "(default) Apply the expression to each document in each yaml file in sequence",
 		Example: `
 # Reads field under the given path for each file
 yq e '.a.b' f1.yml f2.yml 
@@ -67,6 +67,27 @@ func evaluateSequence(cmd *cobra.Command, args []string) (cmdError error) {
 
 	stat, _ := os.Stdin.Stat()
 	pipingStdIn := (stat.Mode() & os.ModeCharDevice) == 0
+	yqlib.GetLogger().Debug("pipingStdIn: %v", pipingStdIn)
+
+	yqlib.GetLogger().Debug("stat.Mode(): %v", stat.Mode())
+	yqlib.GetLogger().Debug("ModeDir: %v", stat.Mode()&os.ModeDir)
+	yqlib.GetLogger().Debug("ModeAppend: %v", stat.Mode()&os.ModeAppend)
+	yqlib.GetLogger().Debug("ModeExclusive: %v", stat.Mode()&os.ModeExclusive)
+	yqlib.GetLogger().Debug("ModeTemporary: %v", stat.Mode()&os.ModeTemporary)
+	yqlib.GetLogger().Debug("ModeSymlink: %v", stat.Mode()&os.ModeSymlink)
+	yqlib.GetLogger().Debug("ModeDevice: %v", stat.Mode()&os.ModeDevice)
+	yqlib.GetLogger().Debug("ModeNamedPipe: %v", stat.Mode()&os.ModeNamedPipe)
+	yqlib.GetLogger().Debug("ModeSocket: %v", stat.Mode()&os.ModeSocket)
+	yqlib.GetLogger().Debug("ModeSetuid: %v", stat.Mode()&os.ModeSetuid)
+	yqlib.GetLogger().Debug("ModeSetgid: %v", stat.Mode()&os.ModeSetgid)
+	yqlib.GetLogger().Debug("ModeCharDevice: %v", stat.Mode()&os.ModeCharDevice)
+	yqlib.GetLogger().Debug("ModeSticky: %v", stat.Mode()&os.ModeSticky)
+	yqlib.GetLogger().Debug("ModeIrregular: %v", stat.Mode()&os.ModeIrregular)
+
+	// Mask for the type bits. For regular files, none will be set.
+	yqlib.GetLogger().Debug("ModeType: %v", stat.Mode()&os.ModeType)
+
+	yqlib.GetLogger().Debug("ModePerm: %v", stat.Mode()&os.ModePerm)
 
 	out := cmd.OutOrStdout()
 
@@ -92,7 +113,10 @@ func evaluateSequence(cmd *cobra.Command, args []string) (cmdError error) {
 		return err
 	}
 
-	printerWriter := configurePrinterWriter(format, out)
+	printerWriter, err := configurePrinterWriter(format, out)
+	if err != nil {
+		return err
+	}
 	encoder := configureEncoder(format)
 
 	printer := yqlib.NewPrinter(encoder, printerWriter)
@@ -131,6 +155,9 @@ func evaluateSequence(cmd *cobra.Command, args []string) (cmdError error) {
 	case 1:
 		if nullInput {
 			err = streamEvaluator.EvaluateNew(processExpression(args[0]), printer, "")
+		} else if pipingStdIn && args[0] != "-" && !maybeFile(args[0]) {
+			// must have given a single expression and piping input from stdin
+			err = streamEvaluator.EvaluateFiles(processExpression(args[0]), []string{"-"}, printer, leadingContentPreProcessing, decoder)
 		} else {
 			err = streamEvaluator.EvaluateFiles(processExpression(""), []string{args[0]}, printer, leadingContentPreProcessing, decoder)
 		}
