@@ -11,6 +11,7 @@ import (
 	"testing"
 
 	"github.com/mikefarah/yq/v4/test"
+	"gopkg.in/op/go-logging.v1"
 	yaml "gopkg.in/yaml.v3"
 )
 
@@ -26,6 +27,12 @@ type expressionScenario struct {
 	dontFormatInputForDoc bool // dont format input doc for documentation generation
 }
 
+func TestMain(m *testing.M) {
+	logging.SetLevel(logging.ERROR, "")
+	code := m.Run()
+	os.Exit(code)
+}
+
 func NewSimpleYamlPrinter(writer io.Writer, outputFormat PrinterOutputFormat, unwrapScalar bool, colorsEnabled bool, indent int, printDocSeparators bool) Printer {
 	return NewPrinter(NewYamlEncoder(indent, colorsEnabled, printDocSeparators, unwrapScalar), NewSinglePrinterWriter(writer))
 }
@@ -46,7 +53,6 @@ func readDocumentWithLeadingContent(content string, fakefilename string, fakeFil
 
 func testScenario(t *testing.T, s *expressionScenario) {
 	var err error
-
 	node, err := NewExpressionParser().ParseExpression(s.expression)
 	if err != nil {
 		t.Error(fmt.Errorf("Error parsing expression %v of %v: %w", s.expression, s.description, err))
@@ -221,7 +227,7 @@ func documentOperatorScenario(t *testing.T, w *bufio.Writer, i interface{}) {
 func documentInput(w *bufio.Writer, s expressionScenario) (string, string) {
 	formattedDoc := ""
 	formattedDoc2 := ""
-	command := "eval"
+	command := ""
 
 	envCommand := ""
 
@@ -252,19 +258,19 @@ func documentInput(w *bufio.Writer, s expressionScenario) (string, string) {
 			writeOrPanic(w, "And another sample another.yml file of:\n")
 			writeOrPanic(w, fmt.Sprintf("```yaml\n%v```\n", formattedDoc2))
 			files = "sample.yml another.yml"
-			command = "eval-all"
+			command = "eval-all "
 		}
 
 		writeOrPanic(w, "then\n")
 
 		if s.expression != "" {
-			writeOrPanic(w, fmt.Sprintf("```bash\n%vyq %v '%v' %v\n```\n", envCommand, command, s.expression, files))
+			writeOrPanic(w, fmt.Sprintf("```bash\n%vyq %v'%v' %v\n```\n", envCommand, command, s.expression, files))
 		} else {
-			writeOrPanic(w, fmt.Sprintf("```bash\n%vyq %v %v\n```\n", envCommand, command, files))
+			writeOrPanic(w, fmt.Sprintf("```bash\n%vyq %v%v\n```\n", envCommand, command, files))
 		}
 	} else {
 		writeOrPanic(w, "Running\n")
-		writeOrPanic(w, fmt.Sprintf("```bash\n%vyq %v --null-input '%v'\n```\n", envCommand, command, s.expression))
+		writeOrPanic(w, fmt.Sprintf("```bash\n%vyq %v--null-input '%v'\n```\n", envCommand, command, s.expression))
 	}
 	return formattedDoc, formattedDoc2
 }
